@@ -25,6 +25,7 @@ class Context:
             self.can_upload = self.role in ['member', 'admin', 'superadmin']
 
         self.config_filepath = os.path.expanduser('.oort.ini')
+        self.current_date = config.get('current_date', self._get_current_date())
 
         self._autostart = True
         self._payload = {}
@@ -49,6 +50,14 @@ class Context:
         for key, value in kwargs.items():
             self._payload[group][key] = value
 
+    def payload_group_append(self, group, **kwargs):
+        if group not in self._payload.keys():
+            self._payload[group] = {}
+        for key, value in kwargs.items():
+            if key not in self._payload.keys():
+                self._payload[key] = []
+            self._payload[key].append(value)
+
     def get_group_payload(self, group, key):
         if not group in self._payload.keys():
             return None
@@ -60,8 +69,7 @@ class Context:
         json_data = json.dumps(self._payload)
         return f"data:{json_data}\n\n"
 
-    @property
-    def current_date(self):
+    def _get_current_date(self):
         before_noon = datetime.datetime.now().hour < 12
         if before_noon:
             return (datetime.datetime.now() - datetime.timedelta(days=1)).date().isoformat()
