@@ -23,10 +23,7 @@ def uploads():
         count = 0
         while True:
             if count % 300 == 0:
-                yield state.sync_telescopes_and_night_logs()
-
-            if (count < 30 and count % 10 == 0) or count % 60 == 0:
-                yield state.sync_observations_and_calibrations()
+                yield state.sync_telescopes()
 
             yield state.sync_calibrations_uploads()
             yield state.sync_observations_uploads()
